==> CGFeedMaker-1.0.15.tar.gz: CGFeedMaker/action.defaultadmin.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFeedMaker - A flexible tool for the creation and management
#         of RSS Feeds
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

# Tab Headers
echo $this->StartTabHeaders();
if( $this->CheckPermission('Manage RSS Feeds') )
{
  echo $this->SetTabHeader('feeds',$this->Lang('feeds'));
  echo $this->SetTabHeader('categories',$this->Lang('categories'));
}
if( $this->CheckPermission('Modify Site Preferences') )
{
  echo $this->SetTabHeader('settings',$this->Lang('settings'));
}
echo $this->EndTabHeaders();


# Tab Bodies
echo $this->StartTabContent();
if( $this->CheckPermission('Manage RSS Feeds') )
{
  echo $this->StartTab('feeds',$params);
  include(dirname(__FILE__).'/function.admin_feeds_tab.php');
  echo $this->EndTab();

  echo $this->StartTab('categories',$params);
  include(dirname(__FILE__).'/function.admin_categories_tab.php');
  echo $this->EndTab();
}
if( $this->CheckPermission('Modify Site Preferences') )
{
  echo $this->StartTab('settings',$params);
  include(dirname(__FILE__).'/function.admin_settings_tab.php');
  echo $this->EndTab();
}
echo $this->EndTabContent();

#
# EOF
#
?>

==> CGFeedMaker-1.0.19.tar.gz: CGFeedMaker/action.defaultadmin.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFeedMaker - A flexible tool for the creation and management
#         of RSS Feeds
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

# Tab Headers
echo $this->StartTabHeaders();
if( $this->CheckPermission('Manage RSS Feeds') ) {
  echo $this->SetTabHeader('feeds',$this->Lang('feeds'));
  echo $this->SetTabHeader('categories',$this->Lang('categories'));
}
if( $this->CheckPermission('Modify Site Preferences') ) {
  echo $this->SetTabHeader('settings',$this->Lang('settings'));
}
echo $this->EndTabHeaders();


# Tab Bodies
echo $this->StartTabContent();
if( $this->CheckPermission('Manage RSS Feeds') ) {
  echo $this->StartTab('feeds',$params);
  include(__DIR__.'/function.admin_feeds_tab.php');
  echo $this->EndTab();

  echo $this->StartTab('categories',$params);
  include(__DIR__.'/function.admin_categories_tab.php');
  echo $this->EndTab();
}
if( $this->CheckPermission('Modify Site Preferences') ) {
  echo $this->StartTab('settings',$params);
  include(__DIR__.'/function.admin_settings_tab.php');
  echo $this->EndTab();
}
echo $this->EndTabContent();

#
# EOF
#
?>
